@@ -4,12 +4,12 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
-has minify => sub { shift->_app->mode ne 'development' };
+has minify => sub { shift->_app->mode eq 'development' ? 0 : 1 };
 
 has route => sub {
-  shift->_app->routes->route('/asset/:checksum/:name')->via(qw( HEAD GET ))
+  shift->_app->routes->route('/asset/:checksum/:name')->via(qw(HEAD GET))
     ->name('assetpack')->to(cb => \&_serve);
 };
 
@@ -62,6 +62,7 @@ sub process {
   $self->_app->log->debug(qq(Processed asset "$topic".));
   $self->{by_checksum}{$_->checksum} = $_ for @$assets;
   $self->{by_topic}{$topic} = $assets;
+  $self->route;    # make sure we add the route to the app
   $self;
 }
 
@@ -101,6 +102,19 @@ sub register {
 
 sub _app { shift->ua->server->app }
 
+sub _correct_mode {
+  my ($self, $args) = @_;
+
+  while ($args =~ /\[(\w+)([!=]+)([^\]]+)/g) {
+    my $v = $1 eq 'minify' ? $self->minify : $self->_app->$1;
+    diag "Checking $1: $v $2 $3" if DEBUG == 2;
+    return 0 if $2 eq '==' and $v ne $3;
+    return 0 if $2 eq '!=' and $v eq $3;
+  }
+
+  return 1;
+}
+
 sub _pipes {
   my ($self, $names) = @_;
 
@@ -128,9 +142,11 @@ sub _process_from_def {
 
   for (split /\r?\n/, $asset->slurp) {
     s/\s*\#.*//;
-    if (/^\<(\S*)\s+(.+)/) {
-      my $asset = $self->store->asset($2);
-      bless $asset, 'Mojolicious::Plugin::AssetPack::Asset::Null' if $1 eq '<';
+    if (/^\<(\S*)\s+(\S+)\s*(.*)/) {
+      my ($class, $url, $args) = ($1, $2, $3);
+      next unless $self->_correct_mode($args);
+      my $asset = $self->store->asset($url);
+      bless $asset, 'Mojolicious::Plugin::AssetPack::Asset::Null' if $class eq '<';
       push @{$process{$topic}}, $asset;
     }
     elsif (/^\!\s*(.+)/) { $topic = $1; }
@@ -179,10 +195,7 @@ sub _tag_helpers {
     ->map(
     sub {
       my $tag_helper = $_->format eq 'js' ? 'javascript' : 'stylesheet';
-      my $url
-        = $base_url
-        . $route->render(
-        {checksum => $_->checksum, format => $_->format, name => $_->name});
+      my $url = $base_url . $route->render($_->TO_JSON);
       $c->$tag_helper($url, @attrs);
     }
     )->join("\n");
@@ -203,7 +216,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.04
+1.05
 
 =head1 SYNOPSIS
 
@@ -353,6 +366,9 @@ responds to HEAD and GET requests and calls
 L<serve_asset()|Mojolicious::Plugin::AssetPack::Store/serve_asset> on L</store>
 to serve the asset.
 
+The default route will be built and added to the L<application|Mojolicious>
+when L</process> is called the first time.
+
 See L<Mojolicious::Plugin::AssetPack::Guides::Cookbook/ASSETS FROM CUSTOM DOMAIN>
 for an example on how to customize this route.
 
